<template>
  <div class="create">
    <main>
      <div class="mainContent">
        <el-form
          ref="formRef"
          label-width="140px"
          :rules="createRules"
          autoComplete="on"
          :model="form"
          label-position="right"
        >
          <!-- 单兵名称 -->
          <el-form-item class="optionItem" label="单兵名称:" prop="name">
            <el-input
              v-model="form.name"
              placeholder="请填写单兵名称"
            ></el-input>
          </el-form-item>
          <!-- 单兵编号 -->
          <el-form-item class="optionItem" label="单兵编号:" prop="code">
            <el-input
              v-model="form.code"
              placeholder="请填写单兵编号"
            ></el-input>
          </el-form-item>
          <!-- 使用人员 -->
          <el-form-item class="optionItem" label="使用人员:" prop="user">
            <el-input
              v-model="form.user"
              placeholder="请填写使用人员"
            ></el-input>
          </el-form-item>
          <!-- 联系方式 -->
          <el-form-item class="optionItem" label="联系方式:" prop="phone">
            <el-input
              v-model="form.phone"
              placeholder="请填写联系方式"
            ></el-input>
          </el-form-item>
          <!-- 部门 -->
          <el-form-item class="optionItems" label="所属部门:" prop="departId">
            <departTree
              :depart="userDepart"
              @selectDepart="selectDepart"
            ></departTree>
          </el-form-item>
          <el-form-item>
            <div class="optionBtn">
              <el-button
                type="primary"
                class="btn submit"
                @click.native.prevent="handleUpdateLawCar"
                >确认
              </el-button>
            </div>
          </el-form-item>
        </el-form>
      </div>
    </main>
  </div>
</template>
  <script>
import { validatePhone, validateName } from "@/utils/validate";

import { createNamespacedHelpers } from "vuex";
const { mapActions } = createNamespacedHelpers("handheldTerminal");
import departTree from "@/components/departTree/index.vue";
export default {
  components: {
    departTree,
  },
  data() {
    const checkName = (rule, value, callback) => {
      if (value) {
        callback();
      } else {
        callback(new Error("单兵名称不能为空"));
      }
    };
    const checkCode = (rule, value, callback) => {
      if (value) {
        callback();
      } else {
        callback(new Error("单兵编码不能为空"));
      }
    };
    const checkDepartId = (rule, value, callback) => {
      if (value) {
        callback();
      } else {
        callback(new Error("所属部门不能为空"));
      }
    };
    const checkUser = (rule, value, callback) => {
      if (value) {
        callback();
      } else {
        callback(new Error("使用人员不能为空"));
      }
    };
    const checkPhone = (rule, value, callback) => {
      if (value) {
        if (validatePhone(value)) {
          callback();
        } else {
          callback(new Error("请输入正确的手机号"));
        }
      } else {
        callback(new Error("手机号码不能为空"));
      }
    };
    return {
      form: {
        name: "",
        code: "",
        user: "",
        phone: "",
        departName: "",
        departId: 0,
      },
      createRules: {
        departId: [
          {
            required: true,
            trigger: "blur",
            validator: checkDepartId,
          },
        ],
        name: [
          {
            required: true,
            trigger: "blur",
            validator: checkName,
          },
        ],
        code: [
          {
            required: true,
            trigger: "blur",
            validator: checkCode,
          },
        ],
        user: [
          {
            required: true,
            trigger: "blur",
            validator: checkUser,
          },
        ],
        phone: [
          {
            required: true,
            trigger: "blur",
            validator: checkPhone,
          },
        ],
        // id: 0,
        ownerName: [
          {
            required: true,
            trigger: "blur",
            validator: checkName,
          },
        ],
        // vehicleUser: [
        //     {
        //         required: true, trigger: 'blur', validator: checkUser
        //     }
        // ]
      },
      userDepart: {},
      mylabel: "",
      departList: [],
      defaultProps: {
        children: "children",
        label: "departName",
      },
    };
  },
  created() {
    // 初始化数据
    this.form = this.info;
    if (!this.form.departName) {
      this.form.departName = this.form.pdepartName;
    }
    this.userDepart = {
      departId: this.form.departId,
      departName: this.form.departName,
    };
  },

  watch: {
    info(newVal) {
      this.form = newVal; //对父组件传过来的值进行监听，如果改变也对子组件内部的值进行改变
    },
  },
  methods: {
    ...mapActions(["saveHandheldTerminal", "updateHandheldTerminal"]),
    // 修改执法车
    handleUpdateLawCar() {
      this.$refs.formRef.validate((valid) => {
        if (valid) {
          const { form } = this;
          if (form.id > 0) {
            this.updateHandheldTerminal(form).then((res) => {
              this.$message({
                type: "success",
                message: "修改手持设备成功",
              });
              this.$emit("closeDialog", { flag: false, index: 1 });
            });
          } else {
            this.saveHandheldTerminal(form).then((res) => {
              this.$message({
                type: "success",
                message: "保存手持设备成功",
              });
              this.$emit("closeDialog", { flag: false, index: 1 });
            });
          }
        } else {
          return false;
        }
      });
    },

    selectDepart(depart) {
      if (depart) {
        this.form.departId = depart.departId;
        this.form.departName = depart.departName;
      }
    },
  },
  props: ["info", "closeDialog"],
};
</script>
  <style lang="scss" scoped>
.create {
  border-radius: 1px;
  // background-color: #09152f;

  main {
    // border: 1px solid #fff;
    text-align: left;
    padding: 0 55px;
    // background-color: #09152f;
    padding-bottom: 50px;

    .mainContent {
      display: flex;
      justify-content: center;
      padding-top: 50px;

      .el-form-item__content {
        width: 400px;

        .el-select {
          width: 100%;
        }
      }

      .optionHandleSp {
        display: flex;

        .areaNumber,
        .moreNumber {
          flex: 1;
        }

        .telNumber {
          flex: 2;
        }
      }

      .optionBtn {
        display: flex;
        margin-top: 20px;

        .btn {
          padding: 12px 50px;
        }
      }
    }
  }

  // &::v-deep .el-textarea__inner {
  //   background-color: #09152f;
  //   border: 1px solid #17324c;
  // }

  // ::v-deep .el-form-item__label {
  //   color: #4b9bb7;
  // }

  // ::v-deep .el-input__inner {
  //   background-color: #09152f;
  //   border: 1px solid #17324c;
  // }
}
</style>